%global binname acme.sh

Name:       acme-sh
Version:    2.8.6
Release:    1%{?dist}
Summary:    An ACME client written purely in POSIX Shell
Url:        https://github.com/acmesh-official/acme.sh
License:    GPLv3
Source0:    https://github.com/acmesh-official/%{binname}/archive/%{version}.tar.gz
Source1:    %{binname}.sysconfig
Source2:    %{name}.service
Source3:    %{name}.timer
Source4:    %{binname}.logrotate
Patch1:     0001-fix-sudo-detection.patch

BuildArch:      noarch
Requires:       /usr/bin/sh
Requires:       systemd
%if "0%{?rhel}" >= "8" || 0%{?fedora}
BuildRequires:  systemd-rpm-macros
%else
BuildRequires:  systemd
%endif

%description
Acme.sh is an ACME client written purely in POSIX Shell language. It implements
the full ACME protocol and supports both ACMEv1 and ACMEv2 as well as ACMEv2
wildcard certificates.

It can automatically issue, renew and install certificates and supports a
wide variety of DNS provider APIs for DNS-01 challenges.

#-- PREP, BUILD & INSTALL -----------------------------------------------------#
%prep
%autosetup -p1 -n %{binname}-%{version}

# replace macros in source files
sed -i -e "s|%%{_bindir}|%{_bindir}|g" \
       -e "s|%%{_sbindir}|%{_sbindir}|g" \
       -e "s|%%{_libexecdir}|%{_libexecdir}|g" \
       -e "s|%%{_sysconfdir}|%{_sysconfdir}|g" \
       -e "s|%%{_initddir}|%{_initddir}|g" \
       -e "s|%%{_localstatedir}|%{_localstatedir}|g" \
       -e "s|%%{_sharedstatedir}|%{_sharedstatedir}|g" \
       -e "s|%%{_rundir}|%{_rundir}|g" \
       -e "s|%%{_pkgdocdir}|%{_pkgdocdir}|g" \
       -e "s|%%{_datadir}|%{_datadir}|g" \
       -e "s|%%{name}|%{name}|g" \
       -e "s|%%{binname}|%{binname}|g" \
       %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4}

# mangle shebangs
find . -type f -name "*.sh" -exec sed -i 's\#!/usr/bin/env sh\#!/usr/bin/sh\g' {} +

mv deploy/README.md README-deploy.md
mv dnsapi/README.md README-dnsapi.md

%build
# nothing to build

%install
install -p -d -m 0755 %{buildroot}/%{_bindir}
install -p -d -m 0755 %{buildroot}/%{_unitdir}
install -p -d -m 0755 %{buildroot}/%{_sysconfdir}/sysconfig
install -p -d -m 0755 %{buildroot}/%{_sysconfdir}/sysconfig
install -p -d -m 0755 %{buildroot}/%{_sysconfdir}/logrotate.d
install -p -m 0644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/logrotate.d/%{binname}
install -p -d -m 0755 %{buildroot}/%{_datadir}/%{binname}/
install -p -d -m 0700 %{buildroot}/%{_sharedstatedir}/%{binname}/

install -p -d -m 0755 %{buildroot}/%{_datadir}/%{binname}/deploy
install -p -d -m 0755 %{buildroot}/%{_datadir}/%{binname}/dnsapi
install -p -d -m 0755 %{buildroot}/%{_datadir}/%{binname}/notify
install -p -m 0755 %{binname} %{buildroot}/%{_datadir}/%{binname}/%{binname}
install -m 0755 deploy/*.sh %{buildroot}/%{_datadir}/%{binname}/deploy
install -m 0755 dnsapi/*.sh %{buildroot}/%{_datadir}/%{binname}/dnsapi
install -m 0755 notify/*.sh %{buildroot}/%{_datadir}/%{binname}/notify

install -p -m 0755 %{SOURCE1} %{buildroot}/%{_sysconfdir}/sysconfig/%{binname}
install -p -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/%{name}.service
install -p -m 0644 %{SOURCE3} %{buildroot}/%{_unitdir}/%{name}.timer

ln -sf %{_datadir}/%{binname}/%{binname} %{buildroot}/%{_bindir}/%{binname}

#-- SCRIPTLETS -----------------------------------------------------------------#
%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

#-- FILES ---------------------------------------------------------------------#
%files
%doc README.md
%doc README-deploy.md
%doc README-dnsapi.md
%license LICENSE.md
%{_bindir}/%{binname}
%{_datadir}/%{binname}/
%{_unitdir}/%{name}.*
%dir %attr(0700, root, -)  %{_sharedstatedir}/%{binname}/
%config(noreplace) %{_sysconfdir}/logrotate.d/%{binname}
%config(noreplace) %{_sysconfdir}/sysconfig/%{binname}

#-- CHANGELOG -----------------------------------------------------------------#
%changelog
* Thu Aug 20 2020 Christopher Engelhard <ce@lcts.de> 2.8.6-1
- initial non-test release
- specfile and directory cleanup, no functional changes

* Thu Aug 20 2020 Christopher Engelhard <ce@lcts.de> 2.8.6-0.16
- this is a test release
- add patch to fix failed sudo detection when shell is not bash
- mangle shebangs to remove /usr/bin/env
- add /var/lib/acme.sh as global config dir
- add systemd service/timer and sysconfig file to enable auto-renew
  using the global config dir
